Date: 07 11, 2001 10:04:27 AM

# Adding Existing Text Files to a Project

If you already have text files to be analyzed, you can add them directly to the analyzer input directory for processing.

To add files to the analyzer project:

1. Using the file explorer, navigate to the location of your text files.

2. Select the files you want to add to the analyzer project.

3. Navigate to the input folder of the analyzer project.

4. Copy the files into the input folder.

5. To see the added files in the Text Tab, right-click in the Text Tab and select Refresh.